@@ -5,13 +5,16 @@ See :ref:`communications` for more.
 
 .. _UCX: https://github.com/openucx/ucx
 """
+from __future__ import annotations
+
 import functools
 import logging
 import os
 import struct
 import warnings
 import weakref
-from typing import TYPE_CHECKING
+from collections.abc import Awaitable, Callable, Collection
+from typing import TYPE_CHECKING, Any
 
 import dask
 from dask.utils import parse_bytes
@@ -125,11 +128,20 @@ def init_once():
 
     ucp.init(options=ucx_config, env_takes_precedence=True)
 
+    pool_size_str = dask.config.get("distributed.rmm.pool-size")
+
     # Find the function, `cuda_array()`, to use when allocating new CUDA arrays
     try:
         import rmm
 
-        device_array = lambda n: rmm.DeviceBuffer(size=n)
+        def device_array(n):
+            return rmm.DeviceBuffer(size=n)
+
+        if pool_size_str is not None:
+            pool_size = parse_bytes(pool_size_str)
+            rmm.reinitialize(
+                pool_allocator=True, managed_memory=False, initial_pool_size=pool_size
+            )
     except ImportError:
         try:
             import numba.cuda
@@ -140,6 +152,7 @@ def init_once():
                 return a
 
             device_array = numba_device_array
+
         except ImportError:
 
             def device_array(n):
@@ -147,12 +160,11 @@ def init_once():
                     "In order to send/recv CUDA arrays, Numba or RMM is required"
                 )
 
-    pool_size_str = dask.config.get("distributed.rmm.pool-size")
-    if pool_size_str is not None:
-        pool_size = parse_bytes(pool_size_str)
-        rmm.reinitialize(
-            pool_allocator=True, managed_memory=False, initial_pool_size=pool_size
-        )
+        if pool_size_str is not None:
+            warnings.warn(
+                "Initial RMM pool size defined, but RMM is not available. "
+                "Please consider installing RMM or removing the pool size option."
+            )
 
 
 def _close_comm(ref):
@@ -201,7 +213,9 @@ class UCX(Comm):
     4. Read all the data frames.
     """
 
-    def __init__(self, ep, local_addr: str, peer_addr: str, deserialize: bool = True):
+    def __init__(  # type: ignore[no-untyped-def]
+        self, ep, local_addr: str, peer_addr: str, deserialize: bool = True
+    ):
         super().__init__(deserialize=deserialize)
         self._ep = ep
         if local_addr:
@@ -235,9 +249,9 @@ class UCX(Comm):
     async def write(
         self,
         msg: dict,
-        serializers=("cuda", "dask", "pickle", "error"),
+        serializers: Collection[str] | None = None,
         on_error: str = "message",
-    ):
+    ) -> int:
         if self.closed():
             raise CommClosedError("Endpoint is closed -- unable to send message")
         try:
@@ -311,12 +325,14 @@ class UCX(Comm):
             await self.ep.recv(header)
             header = struct.unpack(header_fmt, header)
             cuda_frames, sizes = header[:nframes], header[nframes:]
-        except (
-            ucp.exceptions.UCXCloseError,
-            ucp.exceptions.UCXCanceled,
-        ) + (getattr(ucp.exceptions, "UCXConnectionReset", ()),):
+        except BaseException as e:
+            # In addition to UCX exceptions, may be CancelledError or a another
+            # "low-level" exception. The only safe thing to do is to abort.
+            # (See also https://github.com/dask/distributed/pull/6574).
             self.abort()
-            raise CommClosedError("Connection closed by writer")
+            raise CommClosedError(
+                f"Connection closed by writer.\nInner exception: {e!r}"
+            )
         else:
             # Recv frames
             frames = [
@@ -391,7 +407,9 @@ class UCXConnector(Connector):
     comm_class = UCX
     encrypted = False
 
-    async def connect(self, address: str, deserialize=True, **connection_args) -> UCX:
+    async def connect(
+        self, address: str, deserialize: bool = True, **connection_args: Any
+    ) -> UCX:
         logger.debug("UCXConnector.connect: %s", address)
         ip, port = parse_host_port(address)
         init_once()
@@ -415,10 +433,10 @@ class UCXListener(Listener):
     def __init__(
         self,
         address: str,
-        comm_handler: None,
-        deserialize=False,
-        allow_offload=True,
-        **connection_args,
+        comm_handler: Callable[[UCX], Awaitable[None]] | None = None,
+        deserialize: bool = False,
+        allow_offload: bool = True,
+        **connection_args: Any,
     ):
         if not address.startswith("ucx"):
             address = "ucx://" + address
